/*************************************************************************
**  
**  This program solves the rbc model via GENSYS
**  Author: David N. DeJong
**
**************************************************************************/

/* filename: rbc.prg
**
*/

/*
Goal: convert system of nonlinear model equations into a linear system
of the form

(1)	x(t) = T1x(t-1) + T0z(t) = T1x(t-1) + e(t), 

where Eee' = Q,
x(t) is an nx1 vector of model variables,
and z is a jx1 vector of exogenous disturbances.

Variables (logged deviations from ss xbar) are contained in the nx1 vector x.  
Ordering:
x = [y c i n l k a ]';

*/

new;
dlibrary -a PszTgSen,PsdTgSen;
#include gensys.src
cls;

/* establish global variables */
tme = 0;            // indicator variable used to construct A and B
nvars = 7;          // # of variables included in the model
neulers = 1;        // # of euler equations included in the model
nshocks = 1;        // # of structural shocks
xbar = 0;           // will contain ss values

// establish parameters: alpha, beta, delta, rho, sigeps, phi, psi
let p[7,1] = 0.33 0.975 0.06 0.9, 0.01, 2, 0.5;

/* load procedures needed to solve model */
#include rbc.src

xbar = ln(steady(p));

{TC,T1,T0,RC}=modelsol(p);      // x(t) = TC + T1x(t-1) + T0z(t)
                                // rc[1] = 1: sln exists; rc[2] = 1: sln is unique

f = t1;
g = t0;
q = (t0*p[5])*(t0*p[5])';       // vcv matrix of e(t) = T0z(t)

"lag matrix of system:" t1;?;

#include rbcsts.src

nresp = 21;
horizon = seqa(1,1,nresp);
{stdx,corrx,auto1x,auto2x,resp} = corrproc(f,g,q,nresp);  

"std devs (actual and relative to output), ordering [y c i n l k a ]:";?;
stdx;?;

"correlations across variables:";?;
corrx;?;

"first-order autocorrelation:";?;
diag(auto1x);?;

"corr(y,xlag), x = [y c i n l k a ]:";?;
auto1x[1,.]';?;

library pgraph;
graphset;
_pdate = "";
_psymsiz =  3;
_paxht   = .2;
_pnumht  = .2;
_ptitlht = .3; 

ytics(-0.005,0.015,0.005,0);
begwind;
window(3,3,0);
iii=1; do while iii<=nvars;
    if iii==3;
        ytics(-0.01,0.06,0.01,0);
        xy(horizon,resp[iii,.]'~zeros(nresp,1));
        ytics(-0.005,0.015,0.005,0);
        nextwind;
    else;
        xy(horizon,resp[iii,.]'~zeros(nresp,1));
        nextwind;
    endif;
iii=iii+1; endo;
endwind;